@@ -38,17 +38,15 @@ class cxxISolution: public PHRQ_base
 	std::map < std::string, cxxISolutionComp > &Get_comps(void) {return this->comps;}
 	const std::map < std::string, cxxISolutionComp > &Get_comps(void)const {return this->comps;}
 	void Set_comps(std::map < std::string, cxxISolutionComp > &c) {this->comps = c;}
-	std::map < std::string, cxxChemRxn >  &Get_pe_reactions(void) {return this->pe_reactions;}
-	void Set_pe_reactions(std::map < std::string, cxxChemRxn >  &pe) {this->pe_reactions = pe;}
-	//void dump_xml(std::ostream& os, unsigned int indent = 0)const;
-	//void ConvertUnits(Phreeqc * phreeqc_ptr);
+	std::map<std::string, CReaction>& Get_pe_reactions(void) { return this->pe_reactions; }
+	void Set_pe_reactions(std::map < std::string, CReaction >& pe) { this->pe_reactions = pe; }
 
   protected:
 	friend class cxxISolutionComp;	// for this->pe access
 	std::string units;
 	bool calc_density;
 	std::map < std::string, cxxISolutionComp > comps;
-	std::map <std::string, cxxChemRxn > pe_reactions;
+	std::map <std::string, CReaction> pe_reactions;
 	const char * default_pe;
 };
 
