@@ -70,7 +70,7 @@ public:
 	cxxSurfaceCharge(struct surface_charge *, PHRQ_io *io=NULL);
 	virtual ~cxxSurfaceCharge();
 
-	struct master *Get_psi_master();
+	class master *Get_psi_master();
 	void dump_xml(std::ostream & os, unsigned int indent = 0) const;
 	void dump_raw(std::ostream & s_oss, unsigned int indent) const;
 	void read_raw(CParser & parser, bool check = true);
